@@ -94,7 +94,7 @@ class FacebookScraper:
         return not response.url.startswith('https://m.facebook.com/login.php')
 
     def _generic_get_posts(
-            self, extract_post_fn, iter_pages_fn, page_limit=DEFAULT_PAGE_LIMIT, options=None):
+            self, extract_post_fn, iter_pages_fn, page_limit=DEFAULT_PAGE_LIMIT, options=None, cookie_locale=None):
         counter = itertools.count(0) if page_limit is None else range(page_limit)
 
         if options is None:
@@ -104,4 +104,8 @@ class FacebookScraper:
         for i, page in zip(counter, iter_pages_fn()):
             logger.debug("Extracting posts from page %s", i)
             for post_element in page:
+                if cookie_locale is not None:
+                    print("cookie_locale:%s" % cookie_locale)
+                    self.default_headers['cookie'] = 'locale=%s;' % cookie_locale
+                    self.session.headers.update(self.default_headers)
                 yield extract_post_fn(post_element, options=options, request_fn=self.get)
